clear all
set mem 15g
set matsize 11000
set more off


********  STEP 0: SET GLOBALS **********************
	
	global root "/data/hastings2/CompletedPapers/HHS_ECMA_2017/_final/"
        global infile "${root}input/"
	global tempfile "${root}temp/"
	global outfile "${root}output/"
	global dir_log "${root}output/log/"		

	
	global date "20170206"

cap log close
log using "${dir_log}Step2_Tables3-5_final_${date}.txt", replace

	
*************************************************************************
******** PREP ANSCILLARY DATA FILES ON AFORE CHARACTERISTICS     ********
*************************************************************************

   *** STEP 0.0: Bank branch data *****
   ************************************
   use "${infile}bank_branches_yr_final_avg.dta", clear
      keep id capbranches
      rename capbranches meanbranches 
      merge 1:1 id using "${infile}bank_branches_yr_final_max.dta", assert(3) nogen
      rename capbranches maxbranches
      
      drop muni 
      gen muni=substr(id,1,5)
      rename bank afore_code
        
      keep if year<=2001 
      
      collapse (mean) meanbranches=maxbranches (max) maxbranches=maxbranches, by (muni afore_code)
  
      save "${tempfile}tempbranches.dta", replace


   *** STEP 0.1: Other firm characteristics like past returns, bank and foreign owned *****
   ****************************************************************************************
   ***1. Load returns data 
   use ${infile}returns_98to04.dta, clear
      keep if month=="August 1, 1998" 
      keep afore_code rendrea_sb
      merge m:1 afore_code using "${infile}firm_char.dta", nogenerate
      merge m:1 afore_code using "${infile}inv_characteristics_corrected.dta", nogenerate
      drop if afore_code==.
      save "${tempfile}tempmoreaforevars.dta", replace      	

   
*********************************************************************************************************
******** MARKET SHARE REGRESSIONS:  DOES ADVERTISING INCREASE J'S MARKET SHARE AT A GIVEN COST?  ********
**********************************************************************************************************************
** STEP 1.0:  Load in cell-afore file of betas, market shares, sales force, etc. 
**********************************************************************************************************************
   
   *** 1.0: MERGE VARIABLES ONTO MUNI-CELL PREFERENCE AND MARKET SHARE DATA
   use "${tempfile}temp_betas&ivs.dta", clear
     gen state=substr(muni,1,2)
     tab state
     gen muni2=muni
     replace muni="09001" if state=="09"
   
     merge m:1 afore_code muni using "${tempfile}tempbranches.dta"
     keep if _merge!=2
     egen temp=max(_merge), by(afore_code)
     gen bank=(temp==3)
     drop _merge temp

     drop muni
     rename muni2 muni
     
     replace meanbranches=0 if meanbranches==.     
     replace maxbranches=0 if maxbranches==.

     
     merge m:1 afore_code using "${tempfile}tempmoreaforevars.dta", ///
     assert(3) nogen keepusing(afore_code rendrea_sb1_sief_12m foreign_owner)
     
     ****** Merge on extra census vars we want to use as instruments
     merge m:1 muni using  ${infile}census_extraIVs.dta, assert(2 3) keep(3) nogen

      
     *** 1.1 GENERATE ADDITIONAL VARIABLES NEEDED FOR ANALYSIS     
     egen temp=total(maxbranches), by(cell)
     gen othermaxbranch=temp-maxbranches
     drop temp
     
     gen percimss=MUN_P_WIMSS/(MUN_P_Mas+MUN_P_Fem)
     gen perciste=MUN_P_WISS/(MUN_P_Mas+MUN_P_Fem)       

     xtset cell
     gen flag1=delta<-11
     gen flag2=mktshrC==0
     tab flag1 flag2, m
 
     bysort muni: gen m1=(_n==1)
     bysort cell: gen c1=(_n==1)
     bysort muni afore_code: gen ma1=(_n==1)

     sort cell cost
     cap drop n
     cap drop temp
     bysort cell: gen n=_n
     bysort cell: gen N=_N
     gen cheap4=(n<=4)
     gen cheap4agentes=cheap4*agentes_perimss
     tab afore_code if cheap4  
     egen totalcheapagentes=total(cheap4agentes), by(cell)
      
     *** measures of agentes for outside Afore - - Afore 548 ***
     gen temp=agentes_perimss if afore_code==548
     egen outside_agentes=min(temp), by(muni)
     drop temp
     
     tostring demogroup, gen(temp)
     cap drop xwage4 xage4 male
     gen xwage4=real(substr(temp,1,1))
     gen xage4=real(substr(temp,2,1))
     gen male=real(substr(temp,3,1))
     drop temp
   
     drop sar92sum ivcost ivwage  s92iv*   ISSSTE 
     
     ** label afore_code
     label define aforenames 510 "GénesisMetro" 512 "Zurich" 514 "Tepeyac" 516 "XXI" 530 "Banorte" 532 "Dresdner(AllianzHSBC)" 534 "Profuturo" ///
     536 "AtlánticoPromex" 538 "Principal" 540 "Santander" 542 "Previnter" 544 "ING / Bital" 546 "Capitaliza" 548 "Garante"  ///
     550 "Inbursa" 552 "Banamex" 554 "Bancomer"
     
     label values afore_code aforenames
     save ${tempfile}/temp_cell_data.dta, replace

*************************************************************************************************************
**** STEP 2: RUN REGRESSIONS
*************************************************************************************************************

  ** Exploratory analysis: Muni-Afore-Level Mkrt share regressions
     use ${tempfile}/temp_cell_data.dta, replace
     
     gen temp=meancostM*percimss
     areg agentes_level meancostM wage maxbranches othermax percimss if ma1==1, absorb(afore_code)
     bysort afore_code: reg agentes_level meancostM maxbranches othermax percimss 
     bysort afore_code: reg agentes_level meancostM othermax percimss 
     
  ** Run regressions of cost in a cell on cost in neighboring cells by Afore - what is the correlation?
     regress cost ivcost2 if afore_code==510
     outreg2 ivcost2 using "${outfile}extra/AppendixTable1.xls", bdec(3) excel addstat(R-square, `e(r2_a)') ctitle(510) replace
     levelsof afore_code, local(levels)
     foreach l of local levels {
          regress cost ivcost2 if afore_code==`l'
          outreg2 ivcost2 using "${outfile}extra/AppendixTable1", bdec(3) excel addstat(R-square, `e(r2_a)') ctitle(`l') append
          }            
  
    *** Prep for IV and OLS regressions ****
     tab afore_code if delta==.
     replace delta=0 if delta==.
     
     egen cluster=group(afore_code muni)
     
     gen ivcost2_thous=ivcost2/1000
     egen tempclust=group(afore_code muni)
     
          
     drop temp* 
          
     levelsof afore_code, local(levels)
     foreach l of local levels {
       areg agentes_level ivcost2_th other percimss perciste maxbranches if afore_code==`l', absorb(demog) cluster (muni)
       if `l'==510 {
          outreg2 ivcost2_th other percimss perciste using /// 
          "${outfile}extra/Appendix_newTable1stStage.xls", bdec(3) excel  ///
          addstat (R-squared,e(r2_a) , F-stat, e(F)) ctitle(`l') replace
          }
        else {         
          outreg2 ivcost2_th other percimss perciste using ///
          "${outfile}extra/Appendix_newTable1stStage.xls", bdec(3) excel  ///
          addstat (R-squared,e(r2_a) , F-stat, e(F)) ctitle(`l') append
  	}
  	}      
     

     bysort afore_code: areg agentes_perimss ivcost2 other percimss perciste , absorb(demog) cluster (muni)
     
     ** rescale bcost for the sake of the output being readable
     gen bcost1k=bcost*1000
     
     global outputT3 "outreg2 agentes_perimss maxbranches bank using "${outfile}tablesFigures/Table3.xls", nocons bdec(3) excel"
     global outputT4 "outreg2 agentes_perimss maxbranches bank using "${outfile}tablesFigures/Table4.xls", nocons bdec(3) excel"
     global outputT5a "outreg2 agentes_perimss_total using "${outfile}tablesFigures/Table5a.xls", bdec(3) excel"
     global outputT5b "outreg2 agentes_perimss_total totalcheap using "${outfile}tablesFigures/Table5b.xls", bdec(3) excel"
     
     global delta_rhs1 "(agentes_perimss = i.afore_code*ivcost2) maxbranches bank flag2 "
     global delta_rhs2 "(agentes_perimss = i.afore_code*ivcost2 i.afore_code|other)maxbranches bank flag2 "
     global delta_rhs3 "(agentes_perimss = i.afore_code*ivcost2 i.afore_code|other i.afore_code|percimss i.afore_code|perciste)maxbranches bank flag2 "

        
     ** Main regressions **
     ** POOLED
      local title "Pooled"
      areg delta agentes_perimss maxbranches bank flag2, absorb(cell) cluster(cluster)
      	  sum delta if e(sample)
          local smean=r(mean)
          sum agentes_perimss if e(sample) 
          local smean2=r(mean)
          local sd2=r(sd)
          sum maxbranch if e(sample)
          local smean3=r(mean)
          local sd3=r(sd)
          $outputT3 replace addstat(Mean Delta, `smean', Mean Salesforce, `smean2', StDev Salesforce, `sd2', Mean Branches, `smean3', StDev Branches, `sd3') ctitle(OLS)
      xi: xtivreg2 delta $delta_rhs1, fe first
          $outputT3 append ctitle(IV 1)
      xi: xtivreg2 delta $delta_rhs2, fe first
	  $outputT3 append ctitle(IV 2)
      xi: xtivreg2 delta $delta_rhs3, fe first
          $outputT3 append ctitle(IV 3)

        **** Generate neutral-agente deltas here ****     
        gen delta0a = delta - _b[agentes_perimss]*(agentes_perimss - outside_agentes)
        label var delta0a "Counterfactual delta with 0 agentes for all from model with only level effect of agentes on delta"  
      reg bcost1k agentes_perimss_total if afore_code==510, cluster(muni)
          sum bcost1k if e(sample)
          local smean=r(mean)
          $outputT5a replace addstat(Sampmean, `smean') ctitle (`title')
      reg bcost agentes_perimss_total if afore_code==510, cluster(muni)
	**** Generate neutral-agente alphas here ****
	gen alpha01= bcost - _b[agentes_perimss_total]*agentes_perimss_total    
	label var alpha01 "Counterfactual mean alpha with zero agentes from model with only mean impact"
      reg bcost1k agentes_perimss_total totalcheap if afore_code==510, cluster(muni)
          $outputT5b append addstat(Sampmean, `smean') ctitle (`title')
 
      *** LOW INCOME
      local title "Low Wage"
      local subsamp "xwage4<3"
      xi: xtivreg delta $delta_rhs3 if `subsamp', fe
          sum delta if e(sample)
          local smean=r(mean)
          $outputT4 replace addstat(Sampmean, `smean') ctitle(`title')
      reg bcost1k agentes_perimss_total if afore_code==510 & `subsamp', cluster(muni)
          sum bcost if e(sample)
          local smean=r(mean)
          $outputT5a append addstat(Sampmean, `smean') ctitle (`title')
      
      *** HIGH INCOME
      local title "High Wage"
      local subsamp "xwage4>=3"
      xi: xtivreg delta $delta_rhs3 if `subsamp', fe
          sum delta if e(sample) 
          local smean=r(mean)
          $outputT4 append addstat(Sampmean, `smean') ctitle(`title')
      reg bcost1k agentes_perimss_total if afore_code==510 & `subsamp', cluster(muni)
          sum bcost if e(sample)
          local smean=r(mean)
          $outputT5a append addstat(Sampmean, `smean') ctitle (`title')
       
      *** MALE
      local title "Male"
      local subsamp "male==1"
      xi: xtivreg delta $delta_rhs3 if `subsamp', fe
          sum delta if e(sample) 
          local smean=r(mean)
          $outputT4 append addstat(Sampmean, `smean') ctitle(`title')
      reg bcost1 agentes_perimss_total if afore_code==510 & `subsamp', cluster(muni)
          sum bcost if e(sample)
          local smean=r(mean)
          $outputT5a append addstat(Sampmean, `smean') ctitle (`title')
          
      *** FEMALE
      local title "Female"
      local subsamp "male==0"
      xi: xtivreg delta $delta_rhs3 if `subsamp', fe
          sum delta if e(sample)
          local smean=r(mean)
          $outputT4 append addstat(Sampmean, `smean') ctitle(`title')
      reg bcost1 agentes_perimss_total if afore_code==510 & `subsamp', cluster(muni)
          sum bcost if e(sample)
          local smean=r(mean)
          $outputT5a append addstat(Sampmean, `smean') ctitle (`title')
         
      *** YOUNGER
      local title "Younger"
      local subsamp "xage4<3"
      xi: xtivreg delta $delta_rhs3 if `subsamp', fe
          sum delta if e(sample) 
          local smean=r(mean)
          $outputT4 append addstat(Sampmean, `smean') ctitle(`title')
      reg bcost1 agentes_perimss_total if afore_code==510 & `subsamp', cluster(muni)
          sum bcost if e(sample)
          local smean=r(mean)
          $outputT5a append addstat(Sampmean, `smean') ctitle (`title')
           
      *** OLDER
      local title "Older"
      local subsamp "xage4>=3"
      xi: xtivreg delta $delta_rhs3 if `subsamp', fe
          sum delta if e(sample) 
          local smean=r(mean)
          $outputT4 append addstat(Sampmean, `smean') ctitle(`title')
      reg bcost1 agentes_perimss_total if afore_code==510 & `subsamp', cluster(muni)
          sum bcost if e(sample)
          local smean=r(mean)
          $outputT5a append addstat(Sampmean, `smean') ctitle (`title')
           
      *** LOW COST
      local title "Low Cost"
      local subsamp "cheap4==1"
      xi: xtivreg delta $delta_rhs3 if `subsamp', fe
          sum delta if e(sample)
          local smean=r(mean)
          $outputT4 append addstat(Sampmean, `smean') ctitle(`title')

    *** Now clean up the file ***
    keep muni cell agentes_perimss demogroup afore_code delta* bcost bcost_wage alpha*

    *** Replace deltas for 510 with zeros and save ***
    tab afore_code if delta==.
    foreach var in delta delta0a {
	replace `var'=0 if `var'==. & afore_code==548
     }

    save "${tempfile}/alphasDeltasCounterfactuals.dta", replace


cap log close
*******************
*******************
******  END  ******
*******************
*******************

/****** MAKE DATA FOR MATLAB SIMULATIONS ****/

log using "${infile}matlab/log_outsheet_matlab_${date}.txt", replace
**** Incumbents file - accounts at the start of the system ******
use "${tempfile}/alphasDeltasCounterfactuals.dta", clear
   keep muni afore_code demogroup alpha01 bcost bcost_wage delta delta0a
   rename delta0a newdelta
   rename delta oldelta
   rename alpha01 newalpha
   reshape wide oldelta newdelta, i(muni demogroup) j(afore_code)
sort muni demogroup
save "${tempfile}tempnewdeltas_548_${date}.dta", replace


use "${tempfile}/basedemanddata.dta", clear
  sort nss
  merge nss using "${infile}temp_1perc.dta"
  tab _merge
  keep if _merge==3
  drop _merge
     
  gen int demogroup=xwage4*100+xage4*10+male

  keep nss  sar92sum capped_expsal_*  cs_*  yrs_to_ret inception_afore demogroup  muni wage  age male
  compress

sort muni demo 
save "${tempfile}inception_1perc_${date}.dta", replace


use "${tempfile}inception_1perc_${date}.dta", clear
  merge m:1  muni demo using "${tempfile}tempnewdeltas_548_${date}.dta"
  tab _merge  
  keep if _merge==3
  drop _merge 
  keep  nss sar92sum capped_expsal_1997-inception_afore muni yrs_to_ret demogroup newdelta* newalpha bcost* wage  age male oldelta*
  sort nss 
  duplicates report nss
  drop if bcost==.

  *creating a new nss because matlab has problem reading the nss
  egen nss2=group(nss)
  save "${tempfile}file_matlab_contfact548_${date}.dta", replace
  
  use "${tempfile}file_matlab_contfact548_${date}.dta", clear
  gen afore=inception_afore
  drop nss inception_afore
  order  sar92sum capped_expsal_1997 cs_1997 capped_expsal_1998 cs_1998 capped_expsal_1999 cs_1999 capped_expsal_2000 cs_2000 ///
  capped_expsal_2001 cs_2001 capped_expsal_2002 cs_2002 capped_expsal_2003 cs_2003 capped_expsal_2004 cs_2004 ///
  capped_expsal_2005 cs_2005 capped_expsal_2006 cs_2006 muni yrs_to_ret wage demogroup bcost bcost_wage newalpha ///
  newdelta510 newdelta512 newdelta514 newdelta516 newdelta530 newdelta532 newdelta534 newdelta536 newdelta538 newdelta540 newdelta542 ///
  newdelta544 newdelta546 newdelta548 newdelta550 newdelta552 newdelta554 nss2 afore age male ///
  oldelta510 oldelta512 oldelta514 oldelta516 oldelta530 oldelta532 oldelta534 oldelta536 oldelta538 /// 
  oldelta540 oldelta542 oldelta544 oldelta546 oldelta548 oldelta550 oldelta552 oldelta554

  destring muni, replace
  sort nss afore
  outsheet using "${infile}matlab/file_matlab_contfact_${date}.txt", replace nonames
  
  save "${infile}matlab/incumbents_sample_${date}", replace
  sum
  
  **Make multiple txt files with matrices to read into into MATLAB **
  sort nss
  outsheet age using "${infile}matlab/incumbents_age_${date}.txt", replace nonames
  
  sort nss
  outsheet wage using "${infile}matlab/incumbents_wage_${date}.txt", replace nonames
  
  sort nss
  outsheet male using "${infile}matlab/incumbents_male_${date}.txt", replace nonames
  
  sort nss
  outsheet yrs_to_ret using "${infile}matlab/incumbents_yrstoret_${date}.txt", replace nonames 
  
  sort nss
  outsheet sar92sum using "${infile}matlab/incumbents_sar92sum_${date}.txt", replace nonames
  
  sort nss
  outsheet cs_1997 cs_1998 cs_1999 cs_2000 cs_2001 cs_2002 cs_2003 cs_2004 cs_2005 cs_2006 ///
   using "${infile}matlab/incumbents_cs_${date}.txt", replace nonames
  
  sort nss 
  outsheet capped_expsal_1997 capped_expsal_1998 capped_expsal_1999 capped_expsal_2000 ///
  capped_expsal_2001 capped_expsal_2002 capped_expsal_2003 capped_expsal_2004 capped_expsal_2005 ///
  capped_expsal_2006 using "${infile}matlab/incumbents_cappedexpsalary_${date}.txt", replace nonames
  
  *sort nss
  *outsheet expdias_1997-expdias_2006 using "${outdir}incumbents_expdias_${date}.txt", replace nonames
  
  sort nss
  outsheet newalpha bcost_wage newdelta510-newdelta554 using "${infile}matlab/incumbents_betascounterfactual_${date}.txt", replace nonames
   
  sort nss
  outsheet bcost bcost_wage oldelta510-oldelta554 using "${infile}matlab/incumbents_betasreal_${date}.txt", replace nonames
               
  sort nss
  tostring demogroup, replace
  gen hiwage=(real(substr(demogroup,1,1))>2)     
  gen older=(real(substr(demogroup,2,1))>2)
  gen male2=(real(substr(demogroup,3,1))==1)
  sort nss
  outsheet hiwage older male2  using "${infile}matlab/incumbents_demogs_${date}.txt", replace nonames
  
     
**** Entrants file - used to allow for system growth ******
  use "${infile}postinception_samp1.dta", clear
    
  merge  m:1 muni demo using "${tempfile}tempnewdeltas_548_${date}.dta"
  tab _merge  			
  keep if _merge==3
  drop _merge 
  count 		
  keep nss sar92sum capped_expsal* muni demogroup yrs_to_ret wage age male bcost* oldelta* newdelta* newalpha expdias* cs_*
  
  sort nss 
  duplicates report nss
  drop if bcost==.

  *creating a new nss because matlab has problem reading the nss
  egen nss2=group(nss)
  drop nss
  order  sar92sum capped_expsal_1997 cs_1997 capped_expsal_1998 cs_1998 capped_expsal_1999 cs_1999 capped_expsal_2000 cs_2000 ///
  capped_expsal_2001 cs_2001 capped_expsal_2002 cs_2002 capped_expsal_2003 cs_2003 capped_expsal_2004 cs_2004 ///
  capped_expsal_2005 cs_2005 capped_expsal_2006 cs_2006 muni yrs_to_ret wage demogroup bcost bcost_wage newalpha ///
  newdelta510 newdelta512 newdelta514 newdelta516 newdelta530 newdelta532 newdelta534 newdelta536 newdelta538 newdelta540 newdelta542 ///
  newdelta544 newdelta546 newdelta548 newdelta550 newdelta552 newdelta554 nss2 age male ///
  oldelta510 oldelta512 oldelta514 oldelta516 oldelta530 oldelta532 oldelta534 oldelta536 oldelta538 /// 
  oldelta540 oldelta542 oldelta544 oldelta546 oldelta548 oldelta550 oldelta552 oldelta554
  
  
  sort nss
  outsheet using "${infile}matlab/newentrants_${date}.txt", replace nonames
  
  save "${infile}matlab/newentrants_sample_${date}", replace
  sum 
  
  sort nss
  outsheet age using "${infile}matlab/newentrants_age_${date}.txt", replace nonames
  
  sort nss
  outsheet wage using "${infile}matlab/newentrants_wage_${date}.txt", replace nonames
  
  sort nss
  outsheet male using "${infile}matlab/newentrants_male_${date}.txt", replace nonames
  
  sort nss
  outsheet yrs_to_ret using "${infile}matlab/newentrants_yrstoret_${date}.txt", replace nonames 
  
  sort nss
  outsheet sar92sum using "${infile}matlab/newentrants_sar92sum_${date}.txt", replace nonames
  
  sort nss
  outsheet cs_1997 cs_1998 cs_1999 cs_2000 cs_2001 cs_2002 cs_2003 cs_2004 cs_2005 cs_2006 ///
  using "${infile}matlab/newentrants_cs_${date}.txt", replace nonames
  
  sort nss 
  outsheet capped_expsal_1997 capped_expsal_1998 capped_expsal_1999 capped_expsal_2000 ///
  capped_expsal_2001 capped_expsal_2002 capped_expsal_2003 capped_expsal_2004 capped_expsal_2005 ///
  capped_expsal_2006 using "${infile}matlab/newentrants_cappedexpsalary_${date}.txt", replace nonames
  
  sort nss
  outsheet expdias_1997-expdias_2006 using "${infile}matlab/newentrants_expdias_${date}.txt", replace nonames
  
  sort nss
  outsheet newalpha bcost_wage newdelta510-newdelta554 using "${infile}matlab/newentrants_betascounterfactual_${date}.txt", replace nonames
   
  sort nss
  outsheet bcost bcost_wage oldelta510-oldelta554 using "${infile}matlab/newentrants_betasreal_${date}.txt", replace nonames
  
  use "${infile}aforeinceptionfees.dta", clear
  outsheet afore_code flowfee balfee using "${infile}matlab/inceptionfees_${date}.txt", replace nonames       

cap log close
**********
** END  **
**********

   
   
