
 clear
 clear matrix
 set mem 25g
 
********  STEP 0: SET GLOBALS **********************
	
	global root "/data/hastings2/CompletedPapers/HHS_ECMA_2017/_final/"
        global infile "${root}input/"
	global tempfile "${root}temp/"
	global outfile "${root}output/"
	global dir_log "${root}output/log/"		

	
	global date "20170206"

cap log close
log using "${dir_log}Step3_Table6&Figure5_final_${date}.txt", replace

*****************************************************
  
***** STEP 1: CREATE TABLE 6 ************************* 
   use "${tempfile}elasticities_predcost.dta", clear
	gen int demogroup=xwage4*100+xage4*10+male
	merge m:1 muni demogroup afore_code using "${tempfile}/alphasDeltasCounterfactuals.dta" ///
	, assert(3) keep(3) nogen
	
	label values afore_code afname
    
     *** create new choice probabilities for each alternative model ***
	gen num=exp((alpha01+bcost_wage*wage)*cost + delta0a)
	egen denom=total(num), by(nss)
	gen prob0101 = num/denom
	gen elast0101 = (alpha01 + bcost_wage*wage)*prob0101*(1-prob0101)*(cost/prob0101)

	drop num denom
    
	table afore_code, c(mean chosen mean prob_ij mean prob0101 )
	table afore_code, c(mean elasticity mean elast0101 )
  
	keep nss cost* prob* elast* demogroup muni afore_code  male
 
	tostring demogroup, replace
	gen hiwage=(real(substr(demogroup,1,1))>2)     
	gen older=(real(substr(demogroup,2,1))>2)
   
	gen tempcostbase=cost*prob_ij
	gen tempcostneut=cost*prob0101
	egen expcost_base_all=total(tempcostbase), by(nss)
	egen expcost_neut_all=total(tempcostneut), by(nss)
	gen savings_all=expcost_neut_all-expcost_base_all

	rename elasticity elast_base_all
	rename elast0101 elast_neut_all
	foreach v2 in hiwage older male {
	foreach v1 in expcost_base expcost_neut elast_base elast_neut savings  {
	gen `v1'_`v2'=`v1'_all if `v2'==1
	gen `v1'_not`v2'=`v1'_all if `v2'==0
	}
	}
   
	collapse (mean) expcost_* elast_* savings* 
   
	gen pd_all= expcost_neut_all/expcost_base_all -1
	foreach v in hiwage older male {
	gen pd_`v'=expcost_neut_`v'/expcost_base_`v' -1
	gen pd_not`v'=expcost_neut_not`v'/expcost_base_not`v'-1
	}
   
	gen id=1
	reshape long expcost_base_ expcost_neut_ elast_base_ elast_neut_  savings_ pd_, i(id) j(category) string
   
	** Adding in comparison to minimum monthly pension - pension is 580 pesos per month ** 
	gen min_pension_months = ((expcost_base - expcost_neut)/580)
	gen ave_savings=expcost_base-expcost_neut
	drop expcost_*
   
	replace category="All" if cat=="all"
	replace category="HighWage" if cat=="hiwage"
	replace category="LowWage" if cat=="nothiwage"
	replace category="Younger" if cat=="notolder"
	replace category="Older" if cat=="older"
	replace category="Male" if cat=="male"
	replace category="Female" if cat=="notmale"
   
	outsheet using "${outfile}tablesFigures/Table6.csv", comma replace
     
***** STEP 2: CREATE FIGURE 5 ************************* 

   use "${tempfile}elastcities_coefficients.dta", clear
	keep elasticity elast0101 afore_code agentes_perimss
	collapse (mean) elast_baseline=elasticity elast_neutral=elast0101 mean_agentes=agentes_perimss, by (afore_code)
	sort afore_code
   
	** Generate afore abbreviations for marker labels	 	 
   	gen afore_abv="."
	sort afore_code
	global abv "GM ZR TP XXI BN HSBC PF AP PR SN PV ING CP GR IN BX BC"
	local i=0
	foreach l in $abv {
 		local i = `i' + 1
 		replace afore_abv="`l'" if _n==`i'
 		}
 	*decode afore_code, gen(afore)
 	forvalues i=1/17 {

		local afore_`i'=afore_code[`i']
		local afore_abv_`i'=afore_abv[`i']
		}
		
	gen afore_abv2=lower(afore_abv)

	** Graph scatter plot of elasticities by agentes concentration
   	twoway (scatter elast_baseline mean_agentes if afore_abv!="ZR" & afore_abv!="PV" & afore_abv!="BN" & afore_abv!="PF" & afore_abv!="XXI" & afore_abv!="BC" & afore_abv!="AP", mcolor(cyan) mlcolor(black) msymbol(circle) mlabel(afore_abv) mlabsize(small) mlabcolor(blue) mlabposition(11)) ///
   	       (scatter elast_baseline mean_agentes if afore_abv=="XXI", mcolor(cyan) mlcolor(black) msymbol(circle) mlabel(afore_abv) mlabsize(small) mlabcolor(blue) mlabposition(6)) ///
   	       (scatter elast_baseline mean_agentes if afore_abv=="BC", mcolor(cyan) mlcolor(black) msymbol(circle) mlabel(afore_abv) mlabsize(small) mlabcolor(blue) mlabposition(2)) ///
   	       (scatter elast_baseline mean_agentes if afore_abv=="AP", mcolor(cyan) mlcolor(black) msymbol(circle) mlabel(afore_abv) mlabsize(small) mlabcolor(blue) mlabposition(9)) ///
   	       (scatter elast_baseline mean_agentes if afore_abv=="ZR", mcolor(cyan) mlcolor(black) msymbol(circle) mlabel(afore_abv) mlabsize(small) mlabcolor(blue) mlabposition(2)) ///
   	       (scatter elast_baseline mean_agentes if afore_abv=="PV", mcolor(cyan) mlcolor(black) msymbol(circle) mlabel(afore_abv) mlabsize(small) mlabcolor(blue) mlabposition(12)) ///
   	       (scatter elast_baseline mean_agentes if afore_abv=="BN", mcolor(cyan) mlcolor(black) msymbol(circle) mlabel(afore_abv) mlabsize(small) mlabcolor(blue) mlabposition(6)) ///
   	       (scatter elast_baseline mean_agentes if afore_abv=="PF", mcolor(cyan) mlcolor(black) msymbol(circle) mlabel(afore_abv) mlabsize(small) mlabcolor(blue) mlabposition(2)) ///
   	       (scatter elast_neutral mean_agentes if afore_abv!="IN" & afore_abv!="ZR" & afore_abv!="BC", mcolor(orange) mlcolor(black) msymbol(square) mlabel(afore_abv) mlabsize(small) mlabcolor(black) mlabposition(11)) ///
   	       (scatter elast_neutral mean_agentes if afore_abv=="IN", mcolor(orange) mlcolor(black) msymbol(square) mlabel(afore_abv) mlabsize(small) mlabcolor(black) mlabposition(6)) ///
   	       (scatter elast_neutral mean_agentes if afore_abv=="ZR", mcolor(orange) mlcolor(black) msymbol(square) mlabel(afore_abv) mlabsize(small) mlabcolor(black) mlabposition(2)) ///
   	       (scatter elast_neutral mean_agentes if afore_abv=="BC", mcolor(orange) mlcolor(black) msymbol(square) mlabel(afore_abv) mlabsize(small) mlabcolor(black) mlabposition(2)), ///
   	       xtitle(Mean Agentes Concentration) ytitle(Mean Elasticity) ///
   	       legend(order(1 "Baseline Agents" 10 "Neutral Agents")) ///
   	       ylabel(-3(0.25)0, angle(0) labsize(small)) xlabel(0(0.1)0.75) yline(0, lcolor(red))
   	       graph export ${outfile}tablesFigures/figure5.png, replace
 
 
      *** Make appendix table 2: mkt shr, mktshr base, mktshr NA, elast base, elast neut, %change in revenue
	use "${tempfile}elastcities_coefficients.dta", clear
	
	collapse (mean) chosen prob_ij prob0101 elast* expcost*, by(afore_code)
	gen perc_change_costs= expcost_0101/expcost_base -1
	outsheet using "${outfile}extra/AppendixTable2.csv", comma replace
	
cap log close	
 

**********
** END  **
**********

