/****************************************************************
This do file makes Figure 2 in Hastings, Hortacsu and Syverson
ECMA 2017. 
*****************************************************************/

*** SET UP ******
	
	global root "/data/hastings2/CompletedPapers/HHS_ECMA_2017/_final/"
        global infile "${root}input/"
	global tempfile "${root}temp/"
	global outfile "${root}output/"
	global dir_log "${root}output/log/"		

	
	global date "20170206"

cap log close
log using "${dir_log}Step5_Figure2_final_${date}.txt", replace
	
****************************************************  
**FIGURE II: AFORE FLOW AND BALANCE FEES OVER TIME**
****************************************************

** Use Fees & Returns panel from May 1998 onwards
      
   use ${infile}feesreturns_Historic, clear
   
   ** Add Labels **
   label define afname 510 "GénesisMetro" 512 "Zurich" 514 "Tepeyac" 516 "XXI" 530 "Banorte" 532 "Dresdner(AllianzHSBC)" 534 "Profuturo" ///
   536 "AtlánticoPromex" 538 "Principal" 540 "Santander" 542 "Previnter" 544 "ING / Bital" 546 "Capitaliza" 548 "Garante"  ///
   550 "Inbursa" 552 "Banamex" 554 "Bancomer"
   label values afore_code afname
       
   **Drop obs for post Dec 2000 
   drop if date>td(31 Dec 2000)
      
   **Generate a date in the month year format
   gen tmon=month(date)
   gen tyear=year(date)
   gen month_year = ym(tyear,tmon)
   format month_year %tmMon_YY
      
   **Check which dates are missing
   tab tmon if tyear==1998			
   tab tmon if tyear==1999
   tab tmon if tyear==2000
     
   ** Fix discrepancy in posted fees for Principal in 1999 from official government website **   
   ren bal_fee old_balfee
   gen bal_fee=old_balfee
   replace bal_fee=1 if month_year==tm(1999 Jan) & afore_code==538		/*replacing correct fee for Principal Jan 1999*/
   lab var old_balfee "Bal fee with incorrect fee for Principal Jan99"
   lab var bal_fee "Corrected balance fee for Principal Jan99" 
     
   ren flow_fee old_flowfee
   gen flow_fee=old_flowfee
   replace flow_fee=0.9 if month_year==tm(1999 Jan) & afore_code==538
   lab var old_flowfee "Flow fee with incorrect fee for Principal Jan99"
   lab var flow_fee "Corrected flow fee for Principal Jan99" 
     
   collapse (mean) meanflow=flow_fee meanbal=bal_fee (p50) medflow=flow_fee medbal=bal_fee , by(month_year)
                             
   label var meanflow "Average Flow Fee"
   label var meanbal "Average Balance Fee"
   label var medflow "Median Flow Fee"
   label var medbal "Median Balance Fee" 
      
   ** Make Figure II **
     
        graph twoway (line meanbal month_year, lcolor(blue) lpattern(solid)) (line medbal month_year, lcolor(maroon) lpattern(longdash)) ///
   	(line meanflow month_year, lcolor(dkgreen) lpattern(shortdash)) (line medflow month_year, lcolor(dkorange) lpattern(shortdash)), ///
  	xlabel(461(2)491, angle(45) labsize(small)) ///
  	ylabel(0(0.25)2.0,angle(0) labsize(small)) ///
  	ytitle("Annual Balance fee", size(small)) xtitle("May1998 - Dec2000", size(small)) 

  graph export "${outfile}tablesFigures/FigureII.png", replace
  
  
  cap log close
  	
