/****************************************************************
This do file makes Table 1 in Hastings, Hortacsu and Syverson
ECMA 2017. 
*****************************************************************/

*** SET UP ******
********  STEP 0: SET GLOBALS **********************
	
	global root "/data/hastings2/CompletedPapers/HHS_ECMA_2017/_final/"
        global infile "${root}input/"
	global tempfile "${root}temp/"
	global outfile "${root}output/"
	global dir_log "${root}output/log/"		

	
	global date "20170206"

cap log close
log using "${dir_log}Step6_Table1_final_${date}.txt", replace

*****************************************************
************************************************************************
**TABLE I: DESCRIPTIVE STATISTICS OF AFORES AT THE INCEPTION OF MARKET**
************************************************************************

** Inception market share from base account history file **
	use "${infile}BaseAccountHistoryFile_${date}.dta", clear
	bys inception_afore: gen N=_N
	drop if mi(inception_afore)			
	gen totalN=_N
	duplicates drop inception_afore, force
	gen incep_mktshare=N/totalN
	replace incep_mktshare=incep_mktshare*100
	keep inception_afore incep_mktshare
	gsort -incep_mktshare
	    
	save ${tempfile}tempinception_mktshare, replace 

** Inception fees **	    
	use ${infile}aforeinceptionfees, clear
	** Merge with market shares
        ren afore_code inception_afore
        merge 1:1 inception_afore using ${tempfile}tempinception_mktshare, nogen  
        
	** Format variables **
	gen temp=flowfee/100
        gen tempcontr=0.065		
        gen tempload=temp/tempcontr
        replace tempload=tempload*100
        replace tempload=round(tempload,0.01)
         
        
	gen implied_load=string(tempload,"%9.2fc")
	gen tempflow=string(flowfee,"%9.2fc")
	gen tempbal=string(balfee,"%9.2fc")
	gen tempperc="%"
	foreach x in implied_load tempflow tempbal{
         	ren `x' old`x'
         	egen `x'=concat(old`x' tempperc)
         }
         

        replace incep_mktshare=round(incep_mktshare,0.01)
        gen tempmktshare=string(incep_mktshare,"%9.2fc")
        egen mktshare=concat(tempmktshare tempperc)
        
        rename inception_afore afore_code
        
** Number of agents at inception from historic CONSAR files **
        merge 1:1 afore_code using ${infile}historic_salesforce_counts.dta, nogen
       
	label define afname2 510 "Genesis Metropolitan" 512 "Zurich" 514 "Tepeyac" 516 "XXI" 530 "Banorte Generali" 532 "Bancrecer Dresdner/HSBC)" 534 "Profuturo GNP" ///
	536 "Atlantico Promex" 538 "Principal" 540 "Santander" 542 "Previnter" 544 "ING / Bital" 546 "Capitaliza" 548 "Garante"  ///
	550 "Inbursa" 552 "Banamex" 554 "Bancomer"
	label values afore_code afname2
       
** Outsheet table **
	order afore_code tempflow implied_load tempbal mktshare number_of_agentes
	gsort -number_of_agentes				/*sorting in descending order of agentes*/
	replace mktshare="100%" if mi(afore_code)
	replace afore_code=999 if mi(afore_code)
	lab def afname2 999 "Total", modify
       
	keep afore_code tempflow implied_load tempbal mktshare number_of_agentes incep_mktshare
	save ${tempfile}temptable1.dta, replace
	drop incep_mktshare
	list
	outsheet afore_code tempflow implied_load tempbal mktshare number_of_agentes using "${outfile}tablesFigures/TableI.xls", replace

  cap log close     

