
********  STEP 0: SET GLOBALS **********************
	
	global root "/data/hastings2/CompletedPapers/HHS_ECMA_2017/_final/"
        global infile "${root}input/"
	global tempfile "${root}temp/"
	global outfile "${root}output/"
	global dir_log "${root}output/log/"		

	
	global date "20170206"

cap log close
log using "${dir_log}Step7_Table2Figures3&4_final_${date}.txt", replace

*****************************************************

************************************************************************
**TABLE II: DESCRIPTIVE STATISTICS OF AFORES AT THE INCEPTION OF MARKET**
************************************************************************
use "${tempfile}elastcities_coefficients.dta", replace
   	 egen rank=rank(cost), by(nss)
     	 egen mincost=min(cost), by(nss)			
     	 gen dif=(cost-mincost)/wage if chosen==1
     	 egen mrank=mean(rank), by(afore_code)			
     	 save ${tempfile}temptable2, replace 

use ${tempfile}temptable1, clear
        keep afore_code incep_mktshare number_of_agentes
        drop if afore_code==999
        merge 1:m afore_code using ${tempfile}temptable2
           	  
  	keep if chosen==1


	gen rankdif=rank-mrank  /*the more negative, the better*/
	*gen dif=(cost-mincost)/wage if chosen==1
	gen markup=(cost-mincost)/mincost

collapse (mean) rank mrank dif markup wage incep_mkt male number_ , ///
          by(afore_code)

gsort- number
keep afore_code number incep rank mrank markup dif wage male 
order afore_code number incep rank mrank markup dif wage male 
label var number_ "Afore Sales Force"
label var incep "Market Share"
label var rank "Mean Rank for Own Clients"
label var mrank "Mean Rank Over System"
label var wage "Mean Daily Wage of Clients 1997 Pesos"
label var dif "Mean Savings, Days of Wages"
label var male "Fraction Clients Who Are Male"
label var markup "Mean Mark-up for Own Clients"

outsheet using "${outfile}tablesFigures/TableII.xls", replace

*****  Figure III: 
reg markup number [aweight=incep]
predict xb
label var xb "Linear Regression Prediction"

twoway (scatter markup number_of_agentes [w=incep_mktshare], mcolor(ltblue) msymbol(circle)  ///
        mlabcolor(navy) mfcolor(ltblue) mlcolor(navy)) (line xb number_of_agentes, lcolor(black) lwidth(medthick) ///
	lpattern(solid)) , ytitle(Mean Client Mark-up (%))

graph export "${outfile}tablesFigures/FigureIII.png", replace

drop xb

** Last row of Table II: 
set obs 18
replace afore_code=99 if _n==18
label define afore_code 99 "Correlation with Sales Force" , modify
label values afore_code afore_code 

foreach var in number incep rank mrank wage dif male markup {
corr `var' number_
disp r(rho)
replace `var' = r(rho) if _n==18
}

export excel using "${outfile}tablesFigures/TableII.xls", firstrow(variables) replace
export delimited using "${outfile}tablesFigures/TableII.xls", replace


**** Figure IV ***
clear 
 use ${tempfile}temptable1, clear
        keep afore_code incep_mktshare number_of_agentes
        drop if afore_code==999
        merge 1:m afore_code using ${tempfile}temptable2
           	  
** generate measures of price sensitivity: price of chosen afore relative
** to other afore options
	gen rankdif=rank-mrank if chosen==1 
	cap drop dif
	gen dif=(cost-mincost)/wage if chosen==1
	gen markup=(cost-mincost)/mincost if chosen==1
	gen mmarkup=(cost-mincost)/mincost
	egen meanmuniwage=mean(wage), by(muni)
	egen meanmunicost=mean(cost), by(muni)

   collapse (mean) male meanmuni* rankdif dif markup mmarkup rank mrank cost mincost chosen agentes_per number_, by(afore_code muni)

   gen correlation=.
   levelsof muni, local(levels)
   foreach l of local levels {
	corr markup chosen if muni=="`l'"
	disp r(rho)
	replace correlation=r(rho) if muni=="`l'"
	sum correlation if muni=="`l'"
	}


   collapse (mean) correlation agentes_per meanmuni* male  (sum) tot_agentes=agentes_per, by(muni)
	
   save "${tempfile}temp_fig4.dta", replace

 use "${tempfile}temp_betas&ivs.dta", clear	
   keep agentes_level agentes_level_total muni afore_code mktshrM Nmuni meancostM ivwage cellwage  cell demogroup
   collapse (mean) agentes_level_total agentes_level mktshrM Nmuni meancostM ivwage cellwage, by(muni)
   sum

   merge 1:1 muni using "${tempfile}temp_fig4.dta"

   reg correlation agentes_perimss 

   reg correlation agentes_perimss male meancostM cellwage 

   reg correlation  male meancostM cellwage  
   predict resid, r
   sum correlation
   replace resid=resid+r(mean)

   reg resid agentes_perimss
   predict xb
   label var resid "Mark-up Correlation with Market Share"
   label var agentes_perimss "Mean Sales Force Concetration"
   label var xb "Linea Regression Prediction"
   twoway (scatter resid agentes_perimss) (line xb agentes_perimss), ytitle(Market Share and Mark-up Correlation) ylabel(-.5(.5)1)
 graph export "${outfile}tablesFigures/FigureIV.png", replace

log close
