
function cnumer =calc_numer(samp,m, gridsize,cap1, cap2, adv_level,matsize, sens)

% Arguments
% sample - sample matsize
% m - firm index
% gridsize - grid increment
% cap1 - flow fee cap
% cap2 - balance fee cap
% adv_level - advertising level (1 = base, 2 = neutral)
% matsize - sample size used 

load newdata.mat

% Step I: Specify the fee grid
    
[x,y]=meshgrid( 0:gridsize: cap1 , 0:gridsize: cap2); % 
n1=length(x(:,1));
n2=length(x(1,:));
ym=single(repmat(y, [1,1,matsize]));
xm=single(repmat(x, [1,1,matsize]));

 
% Step II: load data with new workers    
    
discount=[0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 -.05 -.05 -.05 -.05 -.05 -.05 -.05 -.05 -.05;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 -0.02 -0.02 -0.02 -0.02 -0.02;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 -0.02 -0.02 -0.02 -0.02 -0.02;
       0 -0.02 -0.01 -0.01 -0.01 -0.01 -0.01 0 0 0];

   
discount=discount/100;
tenure=cumsum(discount);

% Step III: specificy beta parameters 

betas=betas_m(:,:,adv_level);

%% Step IV: Cut the sample matsize into 5k; samp picks the right account-holder index
capped_salary=capped_salary(samp,:);
betas=betas(samp,:);
wage=wage(samp,:);
cs_alt=cs_alt(samp,:);
age=age(samp,:);
yrs_to_ret=yrs_to_ret(samp,:);
sar92sum=sar92sum(samp,:);


% Step V: Specify the  parameters

deltapar=betas(:,3:end); % prod differentiation parameter

% Step VI: Choose price sensitivity counterfactual

lambda_temp = betas(:,1) + betas(:,2).*wage;

if sens==1 
    
    lambda   = lambda_temp  ; % ns vector of lambda_i

else

    lambda   = lambda_temp ...
        -std(lambda_temp).*(lambda_temp>prctile(lambda_temp,75))  ; % ns vector of lambda_i   
        
end


matsize_temp=size(wage,1);


%Step VII: Define 10 years out index for annual cost calculation
temp=[1997 1998 1999 2000 2001 2002 2003 2004 2005 2006]-1996;
nt=size(temp,2);   %number of years going out - 10 years amortization %
yrs_to_ret_m=yrs_to_ret*ones(1,nt);   % matsize_temp x nt matrix %
yrs_disc=max(yrs_to_ret_m+1-ones(matsize_temp,1)*temp,0); % defines the disount level, 0 if you already reached retirement %
                                                % matsize_temp x nt matrix of discount levels for each person in each year %
indicator = (yrs_to_ret_m>=ones(matsize_temp,1)*temp);  % matsize_temp x nt matrix indicating if person i is still non-retired at time t%
capped_salary1     = indicator.*capped_salary; %matsize_temp x nt .* matsize_temp x nt
cs1     = indicator.*cs_alt; 

%Generate contribution in each year if no fees: Non-retirement indicator *
%contribution rate* capped salary + cuotasocial plus compound interest
%since no fees, this is the same for all afores. 
contribution2 = sum(( 0.065*capped_salary1+cs1 )  .*  1.025  .*  (1.05.^(yrs_disc-1)),2); % an matsize_temp x nt matrix %

owncontribution1=zeros(n1,n2,matsize_temp);
  
 
for t=1:nt
    
   owncontribution1=owncontribution1+...
        ( reshape(kron(capped_salary1(:,t)',ones(n1,n2)),[n1,n2,matsize_temp]).*...
        (0.065 - max(0,xm+tenure(m,t)))+ reshape(kron(cs1(:,t)',ones(n1,n2)),[n1,n2,matsize_temp]) ) .*...
        (1+(.05-ym)/2).*(1.05-ym).^(reshape(kron(yrs_disc(:,t)',ones(n1,n2)),[n1,n2,matsize_temp])-1);
    
end
    
   
    
owncost =  (1/1.05).^reshape(kron(yrs_to_ret',ones(n1,n2)),[n1,n2,matsize_temp]).*...
        (reshape(kron(contribution2',ones(n1,n2)),[n1,n2,matsize_temp]) - owncontribution1...
        + reshape(kron(sar92sum',ones(n1,n2)),[n1,n2,matsize_temp]).*...
        (1.05.^reshape(kron(yrs_to_ret',ones(n1,n2)),[n1,n2,matsize_temp])-...
        (1.05-ym).^reshape(kron(yrs_to_ret',ones(n1,n2)),[n1,n2,matsize_temp]) )) ;
    
clear owncontribution1 

%Step VIII: Calculate logit numerator

cnumer=exp( reshape(kron(lambda',ones(n1,n2)),[n1,n2,matsize_temp]).*owncost+...
           reshape( kron(deltapar(:,m)',ones(n1,n2)),[n1,n2,matsize_temp]) );
      
clear owncost
   
cnumer=single(cnumer);
   
end



   
       


       
       