% This script creates the revenue grid by horizon used for the horizon fit
% Each File is in the form `m'rev`j'h`h'; m denotes the firm, j is the sample type, and h is the horizon


function rev=calc_revenue(index,h,matsize_temp,m)

global dirname dirname_pre dirname_output flowcap balcap gridsize ns 


% Step I: Specify the fee grid

[x,y]=meshgrid( 0:gridsize:flowcap , 0:gridsize:balcap);
n1=length(x(:,1));
n2=length(x(1,:));
ym=single(repmat(y, [1,1,matsize_temp])); % replicates the n1 x n2 grid matsize_temp times
xm=single(repmat(x, [1,1,matsize_temp])); % replicates the n1 x n2 grid matsize_temp times

load newdata.mat;
  
discount=[0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 -.05 -.05 -.05 -.05 -.05 -.05 -.05 -.05 -.05;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 -0.02 -0.02 -0.02 -0.02 -0.02;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 -0.02 -0.02 -0.02 -0.02 -0.02;
       0 -0.02 -0.01 -0.01 -0.01 -0.01 -0.01 0 0 0];

   
discount=discount/100;
tenure=cumsum(discount);
nj = size(discount,1);



% Step II: Cut the sample size

rndsamp=index;
capped_salary=capped_salary(rndsamp,:);
wage=wage(rndsamp,:);
cs_alt=cs_alt(rndsamp,:);
age=age(rndsamp,:);
yrs_to_ret=yrs_to_ret(rndsamp,:);
sar92sum=sar92sum(rndsamp,:);
sar92sum_m=single(reshape(kron(sar92sum',ones(n1,n2)),[n1,n2,matsize_temp]));


% Step III: Define h years out index for annual cost calculation
	
fnt=h;
ftemp=[1:h];
fcapped_salary = capped_salary(:,1:fnt);
fcs = cs_alt(:,1:fnt);
fyrs_to_ret=min(yrs_to_ret,h);
fyrs_to_ret_m=fyrs_to_ret*ones(1,fnt);   
fyrs_disc=max(fyrs_to_ret_m+1-ones(matsize_temp,1)*ftemp,0); 
findicator = (fyrs_to_ret_m>=ones(matsize_temp,1)*ftemp);  
fcapped_salary1     = findicator.*fcapped_salary; 
fcs1     = findicator.*fcs;
fcontribution2 = sum(( 0.065*fcapped_salary1+fcs1 )  .*  1.025  .*  (1.05.^(fyrs_disc-1)),2); 
fpvdiscount=(1/1.05).^reshape( kron(min(yrs_to_ret,h)',ones(n1,n2)),[n1,n2,matsize_temp] ); % grid discount factor used to calculate cost in terms of PV
fcontribution2_m=reshape(kron(fcontribution2',ones(n1,n2)),[n1,n2,matsize_temp]);
fyrs_to_ret_m=reshape(kron(fyrs_to_ret',ones(n1,n2)),[n1,n2,matsize_temp]);
  	
fowncontribution1=zeros(n1,n2,matsize_temp);
           
   				 
for t=1:fnt
    
   fowncontribution1=fowncontribution1 +  ...
        ( reshape(kron(fcapped_salary1(:,t)',ones(n1,n2)),[n1,n2,matsize_temp]).*...
        (0.065 - max(0,xm+tenure(m,t)))+ reshape(kron(fcs1(:,t)',ones(n1,n2)),[n1,n2,matsize_temp]) ) .*...
        (1+(.05-ym)/2).*(1.05-ym).^(reshape(kron(fyrs_disc(:,t)',ones(n1,n2)),[n1,n2,matsize_temp])-1);
    
end
           

rev = single(fpvdiscount.*( fcontribution2_m - fowncontribution1 + sar92sum_m.*...
        		(1.05.^fyrs_to_ret_m-(1.05-ym).^fyrs_to_ret_m ) ));

rev=single(rev);
   
   

end
   
       

      
