%
% FUNCTION: Calculates (a) Market shares of Afores Pricing at Cap,  
%                      (b) Percent of Afores Pricing at Cap, and 
%
% This function is used for TABLE 8.
% Arguments:
% model   - model from which to take the flow fees ff and balance fees bb
%
% Output:
% columnVector - composed of [Sum of shares of afores at cap;
%                             Percent of afores at cap]
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function columnVector = calculateAtCap(model)

ff = model(1:17,1);
bb = model(1:17,2);
flowcap = max(ff);
balcap  = max(bb);

hitsCap = (ff>=flowcap) + (bb>=balcap);
hitsCap = (hitsCap>=1); % These are the Afores that hit either cap
mktSharesIfCap = model(1:17,3);            % Mkt shares 
mktSharesIfCap = mktSharesIfCap(hitsCap);  % Mkt shares if at cap
sumMktSharesIfCap = sum(mktSharesIfCap);   % <--- Sum of shares at cap
hitsCap = mean(hitsCap);                   % <--- Percentage at cap

columnVector = [hitsCap; sumMktSharesIfCap];

