% This script runs a counterfactual for Table 8.
% The required counterfactual is for columns 1 and 3 with caps at (2%,2%)
% Feb,2015

% First step: replicate Table 8, column 1.
% Second: change the caps to 2%,2%.
clc 
global dirname dirname_pre dirname_output flowcap balcap gridsize ns matsize
flowcap=.02; % Flow Fee Cap
balcap=.02; % Balance Fee Cap


gridsize=.0005;
%gridsize=.00025; % Grid size increment
ns= 121719; % sample size
matsize=2000; % number of individuals within a file

cd(dirname)
%% Step I: 


run precalc


         
            
%% Calculate the equilibrium with counterfactual
% horiz - horizon fit
% adv - advertising-level coefficients ; 1 = base and 2 = neutral
% sens - price sensitivity level ;  1 = base and 2 = elastic
% govt - govt firm fee ; 1 = base and 2 = government competitor 
%load actual fees and predicted market shares
tic

% Base advertising, base price sensitivity, govt competitor
[ff, bb] = calc_equil_fees(horiz,1,1,2);
modelAux = revshare(ff,bb,ns,1,1);
% Neutral advertising, base price sensitivity, govt competitor
[ffn, bbn] = calc_equil_fees(horiz,2,1,2);
modelAuxN = revshare(ffn,bbn,ns,2,1);
toc


%% Check how many Afores hit the cap

% Base agents
hitsCap = (ff>=flowcap) + (bb>=balcap);
hitsCap = (hitsCap>=1); % These are the Afores that hit either cap
mktSharesIfCap = modelAux(1:17,3); 
mktSharesIfCap = mktSharesIfCap(hitsCap); % These are their market shares
sumMktSharesIfCap = sum(mktSharesIfCap);  % <--- Sum of their shares
hitsCap = mean(hitsCap);                  % <--- Percentage at cap

% Neutral agents
hitsCapN = (ffn>=flowcap) + (bbn>=balcap);
hitsCapN = (hitsCapN>=1); % These are the Afores that hit either cap
mktSharesIfCapN = modelAuxN(1:17,3); 
mktSharesIfCapN = mktSharesIfCapN(hitsCapN); % These are their market shares
sumMktSharesIfCapN = sum(mktSharesIfCapN);   % <--- Sum of their shares
hitsCapN = mean(hitsCapN);                   % <--- Percentage at cap

% Calculate total costs
totCosts = modelAux(18,4);
baseCosts = model1(18,4);
pctChangeInCosts = (totCosts - baseCosts) ./ baseCosts;
totCostsN = modelAuxN(18,4);
pctChangeInCostsN = (totCostsN - baseCosts) ./ baseCosts;

%% Display and save results
XXIfee = ff(4);
XXIbal = bb(4);
XXIshare = modelAux(4,3);


XXIfeeN = ffn(4);
XXIbalN = bbn(4);
XXIshareN = modelAuxN(4,3);


baseModel = model1(1:17,1:3);

Table8Counterfactual = [XXIfee XXIfeeN; ...
                        XXIbal XXIbalN;...
                        XXIshare XXIshareN;...
                        sumMktSharesIfCap sumMktSharesIfCapN;...
                        hitsCap hitsCapN;...
                        pctChangeInCosts, pctChangeInCostsN];

Table8Counterfactual = [[baseModel(4,1);
                        baseModel(4,2);
                        baseModel(4,3);
                        NaN;
                        NaN;
                        NaN] Table8Counterfactual];
                    
xlswrite(strcat(dirname_output,'/Table8Counterfactual.xls'),Table8Counterfactual);   

%% Cost breakdown by demographics
% See costbydemo1213v2.m

clc

ns= 121719; 
cd(dirname)
demo_id = importdata('incumbents_demogs_20170206.txt');

%% Table 11: Counterfactuals with a Govt player (for debugging)
% cd(dirname_output)
% Table11 = importdata('Table11.csv');
% cd(dirname)

% Baseline equilibrium = Model1 = low caps, base adv, base sens, base govt
% [temp_cost, temp_share] = expected_costmatrix(Table11(1:17,1),...
%     Table11(1:17,2),ns,1,1);
% cost = temp_cost(1:80229,:);
% share = temp_share(1:80229,:);
% 
% high_wage0 = sum(sum(share.*cost.*repmat( demo_id(:,1),1,17),1));
% low_wage0 = sum(sum(share.*cost.*repmat( 1- demo_id(:,1),1,17),1));
% 
% old0 =sum(sum(share.*cost.*repmat( demo_id(:,2),1,17),1));
% young0 = sum(sum(share.*cost.*repmat( 1- demo_id(:,2),1,17),1));
% 
% male0 =sum(sum(share.*cost.*repmat( demo_id(:,3),1,17),1));
% fem0 = sum(sum(share.*cost.*repmat( 1- demo_id(:,3),1,17),1));
% 
% basecostbydemo = [low_wage0;high_wage0;fem0;male0;young0;old0];


%% Reminder:
% Base advertising, base price sensitivity, govt competitor
% [ff, bb] = calc_equil_fees(horiz,1,1,2);
% modelAux = revshare(ff,bb,ns,1,1);
% Neutral advertising, base price sensitivity, govt competitor
% [ffn, bbn] = calc_equil_fees(horiz,2,1,2);
% modelAuxN = revshare(ffn,bbn,ns,2,1);
% End Reminder

%% Base adv, base sens, govt comp
[temp_cost, temp_share] = expected_costmatrix(ff,...
    bb,ns,1,1);

cost = temp_cost(1:80229,:);
share = temp_share(1:80229,:);

high_wage1c = sum(sum(share.*cost.*repmat( demo_id(:,1),1,17),1));
low_wage1c = sum(sum(share.*cost.*repmat( 1- demo_id(:,1),1,17),1));

old1c =sum(sum(share.*cost.*repmat( demo_id(:,2),1,17),1));
young1c = sum(sum(share.*cost.*repmat( 1- demo_id(:,2),1,17),1));

male1c =sum(sum(share.*cost.*repmat( demo_id(:,3),1,17),1));
fem1c = sum(sum(share.*cost.*repmat( 1- demo_id(:,3),1,17),1));

cost_counter1c = [low_wage1c;high_wage1c;fem1c;male1c;young1c;old1c];
pctchng_c1c=((cost_counter1c - basecostbydemo)./basecostbydemo);

%% Neutral adv, base sens, govt comp
[temp_cost, temp_share] = expected_costmatrix(ffn,...
    bbn,ns,2,1);

cost = temp_cost(1:80229,:);
share = temp_share(1:80229,:);

high_wage2c = sum(sum(share.*cost.*repmat( demo_id(:,1),1,17),1));
low_wage2c = sum(sum(share.*cost.*repmat( 1- demo_id(:,1),1,17),1));

old2c =sum(sum(share.*cost.*repmat( demo_id(:,2),1,17),1));
young2c = sum(sum(share.*cost.*repmat( 1- demo_id(:,2),1,17),1));

male2c =sum(sum(share.*cost.*repmat( demo_id(:,3),1,17),1));
fem2c = sum(sum(share.*cost.*repmat( 1- demo_id(:,3),1,17),1));

cost_counter2c = [low_wage2c;high_wage2c;fem2c;male2c;young2c;old2c];
pctchng_c2c=((cost_counter2c - basecostbydemo)./basecostbydemo);

%% Create the tables
costbydemotable_app1 = [ basecostbydemo/1000000, ...
    cost_counter1c/1000000, pctchng_c1c*100,...
    cost_counter2c/1000000, pctchng_c2c*100];

costbydemotable_app1 = [counts, costbydemotable_app1 ];

header_app = {'samplesize','base', 'cont1c','cont1d',... %1=Base
    'cont2c','cont2d'};                                  %2=Neutral

table_app1 = [group, [header_app; num2cell(costbydemotable_app1)]];


% Save the table
cell2csv(strcat(dirname_output,'/counterfactualOfTable8CostByDemo.csv'),table_app1);

% To make the analogous to Table 8, we use cont1d and cont2d, which are
% percentage changes for base and neutral adv.

% The order we want is All, Low, High, Male, Female, Young, Old 
% but it's not in order. 

Table8Counterfactual = [Table8Counterfactual;...
       NaN(2,1) costbydemotable_app1(1:2,4) costbydemotable_app1(1:2,6);... %Lo,Hi
       NaN costbydemotable_app1(4,4) costbydemotable_app1(4,6);...          %Male
       NaN costbydemotable_app1(3,4) costbydemotable_app1(3,6);...          %Female
       NaN(2,1) costbydemotable_app1(5:6,4) costbydemotable_app1(5:6,6)];   %Yo,Old
       
                    
xlswrite(strcat(dirname_output,'/Table8Counterfactual.xls'),Table8Counterfactual);





