
%%%SCRIPT: precalc.m%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script creats the precaculations for individual numerator and
% revenue by horizon and afore. Notice that these matrices do not change in
% the best-response iteration so precalculation will save us from having to
% calculate ns x n1 x n2 cost and logit-numerator figures throughout the
% iteration process. The only drawback is we have to use up hard-disk
% space.
% Files are saved as, where m=firm, samp=individual index, and h=horizon:
% 1.) `m'numer`samp'.mat logit numerator with baseline advertising
% 2.) `m'cnumer`samp'.mat logit numerator with neutral advertising
% 3.) `m'rev`samp'h`h'.mat logit numerator with neutral advertising
% 4.) `m'snumer`samp'.mat logit numerator with baseline advertising + inc
%       in price sensitivity
% 5.) `m'scnumer`samp'.mat logit numerator with neutral advertising + inc in
%       price sensitivity
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


global dirname dirname_pre dirname_output flowcap balcap gridsize ns matsize filename






%% Step 3.a: Create numerator and revenue for firms with tenure discounts and firm 1 

tic

% Note firms 9, 12, 16, and 17 have tenure discount so (unfortunately) we have to create
% different cost calculations for these firms




for m=[1,9,12,16,17]
    
  
   
    parfor k=1:floor(ns/matsize)
            [1,m,k]
            globalBridge(dirname,dirname_pre,dirname_output,flowcap,balcap,gridsize,ns,matsize);
            index=(k-1)*matsize+1:k*matsize;
            % calculate numerator and owncost 
            numer =calc_numer(index',m,gridsize,flowcap, balcap, 1,matsize,1) ;
            parsave(fullfile(dirname_pre...
                ,strcat(num2str(m),'numer',num2str(k))), numer);                          
            
            for h=1:10
                
                % use owncost to calculate discounted revenue, which depend
                % on firm horizon.
                
                rev=calc_revenue(index,h,matsize,m);
               
                parsave(fullfile(dirname_pre...
                    ,strcat(num2str(m),'rev'...
                    ,num2str(k),'h',num2str(h))), rev);      
                
            end 
            
      
    end
    
    % Calculate for the last ns-floor(ns/matsize)*matsize sample
    
    index=floor(ns/matsize)*matsize+1:ns;
    
    numer =calc_numer(index',m,gridsize,flowcap, balcap, 1,ns-floor(ns/matsize)*matsize,1);
    parsave(fullfile(dirname_pre...
                ,strcat(num2str(m),'numer',num2str(floor(ns/matsize)+1))), numer);                          
            
           
                  
            for h=1:10
          
                % use owncost to calculate discounted revenue, which depend
                % on firm horizon.
                
                rev=calc_revenue(index,h,ns-floor(ns/matsize)*matsize,m);
                parsave(fullfile(dirname_pre...
                    ,strcat(num2str(m),'rev'...
                    ,num2str(floor(ns/matsize)+1),'h',num2str(h))), rev);                          
            
            end
            
    
     
end

%% Step 3.b: Create numerator for firms without tenure discount (same rev as
% firm 1 so no need to create other rev grids)

    
for m=[2,3,4,5,6,7,8,10,11,13,14,15]
    
    parfor k=1:floor(ns/matsize)
       globalBridge(dirname,dirname_pre,dirname_output,flowcap,balcap,gridsize,ns,matsize);
            
           [2,m,k]
          index=(k-1)*matsize+1:k*matsize;
          % calculate numerator and owncost (undiscounted revenue)  
          numer =calc_numer(index',m,gridsize,flowcap, balcap, 1,matsize,1 );
          parsave(fullfile(dirname_pre...
                ,strcat(num2str(m),'numer',num2str(k))), numer);              
                        
    end
    index=floor(ns/matsize)*matsize+1:ns;
    
    numer =calc_numer(index',m,gridsize,flowcap, balcap, 1,ns-floor(ns/matsize)*matsize,1);
    parsave(fullfile(dirname_pre...
                ,strcat(num2str(m),'numer',num2str(floor(ns/matsize)+1))), numer);                          
       
end


%% Step 4: create numerator with neutral advertising


for m=1:17
    
   parfor k=1:floor(ns/matsize)
        [3,m,k]
          globalBridge(dirname,dirname_pre,dirname_output,flowcap,balcap,gridsize,ns,matsize);
          index=(k-1)*matsize+1:k*matsize;
          % calculate numerator and owncost (undiscounted revenue)  
          numer =calc_numer(index',m,gridsize,flowcap, balcap, 2,matsize,1 );
          parsave(fullfile(dirname_pre...
                ,strcat(num2str(m),'cnumer',num2str(k))), numer);                          
                        
   end
   
   index=floor(ns/matsize)*matsize+1:ns;
  
   
   numer=calc_numer(index',m,gridsize,flowcap, balcap, 2,ns-floor(ns/matsize)*matsize,1 );
            parsave(fullfile(dirname_pre...
                ,strcat(num2str(m),'cnumer',num2str(floor(ns/matsize)+1))), numer); 
     
end


%% Step 5: create numerator with base advertising + increase price
% sensitivity

for m=1:17
    
    parfor k=1:floor(ns/matsize)
           [4,m,k]
            globalBridge(dirname,dirname_pre,dirname_output,flowcap,balcap,gridsize,ns,matsize);
          index=(k-1)*matsize+1:k*matsize;
          % calculate numerator and owncost (undiscounted revenue)  
          numer =calc_numer(index',m,gridsize,flowcap, balcap, 1,matsize,2 );
          parsave(fullfile(dirname_pre...
                ,strcat(num2str(m),'snumer',num2str(k))), numer);              
                        
    end
    
     index=floor(ns/matsize)*matsize+1:ns;
   
     numer=calc_numer(index',m,gridsize,flowcap, balcap, 1,ns-floor(ns/matsize)*matsize,2 );
            parsave(fullfile(dirname_pre...
            ,strcat(num2str(m),'snumer',num2str(floor(ns/matsize)+1))), numer); 
     
end


%% Step 6: create numerator with neutral advertising + increase price
% sensitivity


for m=1:17
    
   parfor k=1:floor(ns/matsize)
        [5,m,k]
          globalBridge(dirname,dirname_pre,dirname_output,flowcap,balcap,gridsize,ns,matsize);
          index=(k-1)*matsize+1:k*matsize;
          % calculate numerator and owncost (undiscounted revenue)  
          numer =calc_numer(index',m,gridsize,flowcap, balcap, 2,matsize,2 );
          parsave(fullfile(dirname_pre...
                ,strcat(num2str(m),'csnumer',num2str(k))), numer);                          
                        
   end
   
  index=floor(ns/matsize)*matsize+1:ns;
  
   numer=calc_numer(index',m,gridsize,flowcap, balcap, 2,ns-floor(ns/matsize)*matsize,2 );
            parsave(fullfile(dirname_pre...
                ,strcat(num2str(m),'csnumer',num2str(floor(ns/matsize)+1))), numer); 
     
end

toc