%%Calculate expected revenue and shares%%%%


function Dat=revshare(ff,bb,ns,adv,sens)

% Input: 
% ff - flow fee
% bb - balance fee
% ns - no of workers
% adv - advertising level ( 1 base and 2 neutral)
% sens - sensitivity counterfactual (1 no change and 2 inc in sensitivity)


load newdata.mat;

discount=[0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 -.05 -.05 -.05 -.05 -.05 -.05 -.05 -.05 -.05;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 -0.02 -0.02 -0.02 -0.02 -0.02;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 -0.02 -0.02 -0.02 -0.02 -0.02;
       0 -0.02 -0.01 -0.01 -0.01 -0.01 -0.01 0 0 0];

cap=1;
discount=discount/100;
nj = size(discount,1);

% Choose advertising level

betas=betas_m(:,:,adv);

%%%%%
lambda_temp = betas(:,1) + betas(:,2).*wage;

% Pick price sensitivity

if sens==1 
    
    lambda   = lambda_temp  ; % ns vector of lambda_i

else

    lambda   = lambda_temp ...
        -std(lambda_temp).*(lambda_temp>prctile(lambda_temp,75))  ; % ns vector of lambda_i   
        
end

lambda_m       =  kron(ones(1,nj),lambda);      

%Define 10 years out index for annual cost calculation
temp=[1997 1998 1999 2000 2001 2002 2003 2004 2005 2006]-1996;
nt=size(temp,2);   %number of years going out - 10 years amortization %
yrs_to_ret_m=yrs_to_ret*ones(1,nt);   % ns x nt matrix %
yrs_disc=max(yrs_to_ret_m+1-ones(ns,1)*temp,0); % defines the disount level, 0 if you already reached retirement %
                                                % ns x nt matrix of discount levels for each person in each year %
indicator = (yrs_to_ret_m>=ones(ns,1)*temp);  % ns x nt matrix indicating if person i is still non-retired at time t%
capped_salary1     = indicator.*capped_salary; %ns x nt .* ns x nt
cs1     = indicator.*cs_alt;
contribution2 = sum(( 0.065*capped_salary1+cs1 )  .*  1.025  .*  (1.05.^(yrs_disc-1)),2); % an ns x nt matrix %


flowfee   = ff;
balancefee = bb;

% CREATING MATRIX OF FLOW FEES USING ASSUMPTIONS
 flowfeem=zeros(nj,nt);   %nafore x nyears to retirement%
       flowfeem(:,1)=flowfee;       %base flow fee in first year%
       for j=2:nt
       flowfeem(:,j)=flowfeem(:,j-1) + discount(:,j);  %replace flow fee in each year with flow fee - tenure discount %
       end
       flowfeem=max(flowfeem,0);  %there shouldn't be any negative flow fees%
          
    
    for j=1:17
           yr_contr             = capped_salary1.* (  0.065-kron( ones(ns,1),flowfeem(j,:))  );
           contribution1         = indicator.*(  yr_contr +cs1  )  .* (1+(0.05-balancefee(j))/2) .* (1.05-balancefee(j)).^(yrs_disc-1);
           flowcosts(:,j)        = contribution2-sum(contribution1,2); %ok  
           balancecosts(:,j)     = sar92sum .* (  1.05.^yrs_to_ret- (1.05-balancefee(j)).^yrs_to_ret ); %ok
    end

cost   = (1/1.05).^kron(ones(1,nj),yrs_to_ret).*min(cap*kron(ones(1,nj)...
    ,contribution2+sar92sum.*(1.05.^yrs_to_ret)),flowcosts+balancecosts);

numerator   = exp( lambda_m.*cost + betas(:,3:end));   %an ns x nj matrix of e^xb for each person i and afore j -ok
denominator = sum(numerator,2);    % an ns x 1 matirx of sum(e^xb) for each person i -ok 
equilprob  = numerator./kron(ones(1,nj),denominator);  % an ns x nj matirx of choice probabilities for i,j -ok
totalcost=sum(cost.*equilprob,1);
Dat=[ff bb mean(equilprob,1)' totalcost'; [99999, 99999, 99999, sum(totalcost)]];

